==> myfaces-core-assembly-2.2.14-src.zip: myfaces-core-module-2.2.14/impl/src/main/java/org/apache/myfaces/lifecycle/ApplyRequestValuesExecutor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.lifecycle;

import javax.faces.context.FacesContext;
import javax.faces.event.PhaseId;
import org.apache.myfaces.view.facelets.ViewPoolProcessor;

/**
 * Implements the apply request values phase (JSF Spec 2.2.2)
 * 
 * @author Nikolay Petrov (latest modification by $Author$)
 * @version $Revision$ $Date$
 */
class ApplyRequestValuesExecutor extends PhaseExecutor
{
    private ViewPoolProcessor viewPoolProcessor;
    private boolean initialized = false;

    public boolean execute(FacesContext facesContext)
    {
        if (facesContext.getViewRoot() == null)
        {
            throw new ViewNotFoundException("A view is required to execute "+facesContext.getCurrentPhaseId());
        }
        facesContext.getViewRoot().processDecodes(facesContext);
        
        ViewPoolProcessor processor = getViewPoolProcessor(facesContext);
        if (processor != null)
        {
            processor.processDeferredNavigation(facesContext);
        }
        return false;
    }

    public PhaseId getPhase()
    {
        return PhaseId.APPLY_REQUEST_VALUES;
    }
    
    private ViewPoolProcessor getViewPoolProcessor(FacesContext context)
    {
        if (!initialized)
        {
            viewPoolProcessor = ViewPoolProcessor.getInstance(context);
            initialized = true;
        }
        return viewPoolProcessor;
    }
}

==> myfaces-core-assembly-3.0.2-src.zip: myfaces-core-module-3.0.2/impl/src/main/java/org/apache/myfaces/lifecycle/ApplyRequestValuesExecutor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.lifecycle;

import jakarta.faces.context.FacesContext;
import jakarta.faces.event.PhaseId;
import org.apache.myfaces.view.facelets.ViewPoolProcessor;

/**
 * Implements the apply request values phase (JSF Spec 2.2.2)
 * 
 * @author Nikolay Petrov (latest modification by $Author$)
 * @version $Revision$ $Date$
 */
class ApplyRequestValuesExecutor extends PhaseExecutor
{
    private ViewPoolProcessor viewPoolProcessor;
    private boolean initialized = false;

    public boolean execute(FacesContext facesContext)
    {
        if (facesContext.getViewRoot() == null)
        {
            throw new ViewNotFoundException("A view is required to execute "+facesContext.getCurrentPhaseId());
        }
        facesContext.getViewRoot().processDecodes(facesContext);
        
        ViewPoolProcessor processor = getViewPoolProcessor(facesContext);
        if (processor != null)
        {
            processor.processDeferredNavigation(facesContext);
        }
        return false;
    }

    public PhaseId getPhase()
    {
        return PhaseId.APPLY_REQUEST_VALUES;
    }
    
    private ViewPoolProcessor getViewPoolProcessor(FacesContext context)
    {
        if (!initialized)
        {
            viewPoolProcessor = ViewPoolProcessor.getInstance(context);
            initialized = true;
        }
        return viewPoolProcessor;
    }
}
